aboutsummaryrefslogtreecommitdiff
path: root/gcc/c-lex.c
diff options
context:
space:
mode:
authorBernardo Innocenti <bernie@develer.com>2004-07-25 19:32:47 +0000
committerBernardo Innocenti <bernie@develer.com>2004-07-25 19:32:47 +0000
commit5ea539a29c77cab64cdb2c65c7bab2a940c8ab7d (patch)
treed642b60901c819286df73b834dd418c53d8bafe4 /gcc/c-lex.c
parent984721c2bd274b4dc4300100d874fffde41f23da (diff)
* c-decl.c (groktypename, groktypename_in_param_context): Rename
variable typename to type_name. * c-lex.c (interpret_float): Likewise. git-svn-id: https://gcc.gnu.org/svn/gcc/trunk@85161 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/c-lex.c')
-rw-r--r--gcc/c-lex.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/gcc/c-lex.c b/gcc/c-lex.c
index 61f39d09b3e..c7d03fb47e4 100644
--- a/gcc/c-lex.c
+++ b/gcc/c-lex.c
@@ -597,24 +597,24 @@ interpret_float (const cpp_token *token, unsigned int flags)
REAL_VALUE_TYPE real;
char *copy;
size_t copylen;
- const char *typename;
+ const char *type_name;
- /* FIXME: make %T work in error/warning, then we don't need typename. */
+ /* FIXME: make %T work in error/warning, then we don't need type_name. */
if ((flags & CPP_N_WIDTH) == CPP_N_LARGE)
{
type = long_double_type_node;
- typename = "long double";
+ type_name = "long double";
}
else if ((flags & CPP_N_WIDTH) == CPP_N_SMALL
|| flag_single_precision_constant)
{
type = float_type_node;
- typename = "float";
+ type_name = "float";
}
else
{
type = double_type_node;
- typename = "double";
+ type_name = "double";
}
/* Copy the constant to a nul-terminated buffer. If the constant
@@ -641,7 +641,7 @@ interpret_float (const cpp_token *token, unsigned int flags)
??? That's a dubious reason... is this a mandatory diagnostic or
isn't it? -- zw, 2001-08-21. */
if (REAL_VALUE_ISINF (real) && pedantic)
- warning ("floating constant exceeds range of \"%s\"", typename);
+ warning ("floating constant exceeds range of \"%s\"", type_name);
/* Create a node with determined type and value. */
value = build_real (type, real);